@@ -1,3 +1,5 @@
+from kdp_api import DatasetPatchRequest
+
 from kdp_connector.configuration.configurationUtil import ConfigurationUtil
 from kdp_connector.configuration.authenticationUtil import AuthenticationUtil
 from kdp_connector.configuration.keycloak_authentication import KeycloakAuthentication
@@ -12,9 +14,9 @@ from kdp_connector.connectors.Storage import StorageApi
 from kdp_connector.connectors.audit_log import AuditLogApi
 from kdp_connector.connectors.audit_log_configs import AuditLogConfigsApi
 from kdp_api.models import SecurityLabelInfoParams
-from kdp_api.model.audit_log_configuration_paginator import AuditLogConfigurationPaginator
-from kdp_api.model.audit_log_configuration import AuditLogConfiguration
-from kdp_api.model.audit_log_paginator import AuditLogPaginator
+from kdp_api.models.audit_log_configuration_paginator import AuditLogConfigurationPaginator
+from kdp_api.models.audit_log_configuration import AuditLogConfiguration
+from kdp_api.models.audit_log_paginator import AuditLogPaginator
 from pandas import DataFrame
 
 class KdpConn(object):
@@ -57,10 +59,9 @@ class KdpConn(object):
         auth_response = auth_util.create_authentication_token(config, email, password, workspace_id, strategy)
         return auth_response
 
-
     # Auth, only applicable if jwt is created for auth-proxy
     def create_proxy_authentication_token(self, first_name: str, workspace_id: str, jwt: str = None,
-                                    strategy: str = 'proxy') -> object:
+                                          strategy: str = 'proxy') -> object:
         """This method will be used to authenticate to KDP. Only request from auth-proxy with be accepted.
 
             :param str first_name: User's first name
@@ -77,42 +78,44 @@ class KdpConn(object):
         auth_response = auth_util.create_proxy_authentication_token(config, first_name, workspace_id, strategy)
         return auth_response
 
-    def create_keycloak_authentication_token(self, realm: str, client_id: str, client_secret: str, username: str, password: str, workspace_id: str, host: str, verify_ssl: True) -> object:
-          """This method will be used to authenticate to Koverse via Keycloak
+    def create_keycloak_authentication_token(self, realm: str, client_id: str, client_secret: str, username: str, password: str, workspace_id: str, host: str,
+                                             verify_ssl: True) -> object:
+        """This method will be used to authenticate to Koverse via Keycloak
 
               :param str realm: Keycloak URL including host, realm, broker, etc.
               :param str client_id: Keycloak Client ID
               :param str client_secret: Keycloak Client Password
-              :param str email: Email for KeyCloak authentication, optional, requires password
+              :param str username: Username for keycloak authentication
               :param str password: Password for Keycloak authentication, optional, requires email
+              :param str host: The keycloak host
               :param str workspace_id: Koverse Workspace ID
+              :param str verify_ssl: Boolean when set true call verifies SSL
 
               :returns: Koverse Authentication token
 
               :rtype: AuthenticationDetails
           """
 
-          keycloakAuth = KeycloakAuthentication()
-          values=f'Configuration values realm:{realm}, client_id:{client_id}, client_secret:{client_secret}, username:{username}, password: {password}, host: {host}, verify_ssl: {verify_ssl}'
-          print(values)
-          keycloakAuth.set_configuration(realm=realm, client_id=client_id, client_secret=client_secret, username=username, password=password, host=host, verify_ssl=verify_ssl)
-          print('Set keycloak configuration')
-          auth_util = AuthenticationUtil()
-          config = self.create_configuration('')
-          print('Calling to get koverse token from keycloak login')
-          return auth_util.get_koverse_token_from_keycloak_login(config=config, keycloak=keycloakAuth, workspace_id=workspace_id)
+        keycloak_auth = KeycloakAuthentication()
 
+        keycloak_auth.set_configuration(realm=realm, client_id=client_id, client_secret=client_secret, username=username, password=password, host=host, verify_ssl=verify_ssl)
+        auth_util = AuthenticationUtil()
+        config = self.create_configuration('')
+
+        print('Calling to get koverse token from keycloak login')
+
+        return auth_util.get_koverse_token_from_keycloak_login(config=config, keycloak=keycloak_auth, workspace_id=workspace_id)
 
     # , kc_username: str, kc_password: str,
     # WRITE
-    def batch_write(self, dataframe, dataset_id: str, jwt: str, batch_size: int = 100, is_async: bool = True):
+    def batch_write(self, dataframe, dataset_id: str, jwt: str, batch_size: int = 100, is_async: bool = False):
         """This method will be used to write batches of data to KDP
 
             :param DataFrame dataframe: Data to write to KDP
             :param str dataset_id: ID of the KDP dataset where the data will be written
             :param str jwt: JWT token
             :param int batch_size: Defaults to 100
-            :param bool is_async: Defaults to True
+            :param bool is_async: Defaults to False
 
             :returns: Set of partitions data was written to
 
@@ -122,16 +125,10 @@ class KdpConn(object):
         write_api = WriteApi(configuration=config)
         return write_api.batch_write(config=config, dataset_id=dataset_id, dataframe=dataframe, batch_size=batch_size, is_async=is_async)
 
-
     # WRITE
-    def batch_write_v2(self,
-            dataframe: DataFrame,
-            dataset_id: str,
-            jwt: str,
-            security_label_info_params: SecurityLabelInfoParams = None,
-            batch_size: int = 100,
-            is_async: bool = True,
-            is_compressed: bool = False):
+    def batch_write_v2(self, dataframe: DataFrame, dataset_id: str, jwt: str, security_label_info_params: SecurityLabelInfoParams = None,
+                       batch_size: int = 100, is_async: bool = True, is_compressed: bool = False):
+
         """This method will be used to write batches of data to KDP
 
             :param DataFrame dataframe: Data to write to KDP
@@ -157,8 +154,6 @@ class KdpConn(object):
             is_async=is_async,
             is_compressed=is_compressed)
 
-
-
     def create_url_ingest_job(self, workspace_id: str, dataset_id: str, url_list, jwt: str) -> str:
         """This method will be used to start a job that ingests files to KDP
 
@@ -192,7 +187,6 @@ class KdpConn(object):
         return query_api.post_lucene_query(config, dataset_id=dataset_id, expression=expression, limit=limit,
                                            offset=offset)
 
-
     def post_document_lucene_query(self, dataset_id: str, jwt: str, expression: str = '', limit: int = 5, offset: int = 0):
         """This method will be used to query document data in KDP datasets using the lucene syntax
 
@@ -209,10 +203,7 @@ class KdpConn(object):
         query_api = QueryApi()
         config = self.create_configuration(jwt)
         return query_api.post_document_lucene_query(config, dataset_id=dataset_id, expression=expression, limit=limit,
-                                           offset=offset)
-
-
-
+                                                    offset=offset)
 
     # READ
     def read_dataset_to_dictionary_list(self, dataset_id: str, jwt: str,
@@ -289,7 +280,7 @@ class KdpConn(object):
 
     # dataset
     def create_dataset(self, name: str, workspace_id: str, jwt: str, description: str = '',
-                       auto_create_indexes: bool = True, schema: str = '{}', search_any_field: bool = True,
+                       auto_create_indexes: bool = True, schema: any = None, search_any_field: bool = True,
                        record_count: int = 0):
         """This method will create a new KDP dataset
 
@@ -298,7 +289,7 @@ class KdpConn(object):
             :param str jwt: JWT token
             :param str description: Description of dataset
             :param bool auto_create_indexes: Whether to automatically index new data
-            :param str schema: Schema of dataset
+            :param dict schema: Schema of dataset
             :param bool search_any_field: Whether to search any field
             :param int record_count: Whether to search any field
 
@@ -308,8 +299,14 @@ class KdpConn(object):
         """
         kdp_api = KdpApi()
         config = self.create_configuration(jwt)
-        return kdp_api.create_dataset(config, name, workspace_id, description, auto_create_indexes, schema,
-                                      search_any_field, record_count)
+        return kdp_api.create_dataset(config,
+                                      name,
+                                      workspace_id,
+                                      description,
+                                      auto_create_indexes,
+                                      {} if schema is None else schema,
+                                      search_any_field,
+                                      record_count)
 
     def get_dataset(self, dataset_id, jwt):
         """This method will get a dataset by id
@@ -325,7 +322,7 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         return kdp_api.get_dataset(config, dataset_id)
 
-    def patch_dataset(self, dataset_id, payload, jwt):
+    def patch_dataset(self, dataset_id, payload: DatasetPatchRequest, jwt):
         """This method will update fields in a dataset
 
             :param str dataset_id: ID of dataset
@@ -340,7 +337,6 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         return kdp_api.patch_dataset(config, dataset_id, payload)
 
-
     def clear_dataset(self, dataset_id, jwt):
         """This method will clear the dataset.
 
@@ -355,7 +351,6 @@ class KdpConn(object):
         write_api = StorageApi()
         return write_api.clear_dataset(config=config, dataset_id=dataset_id)
 
-
     # workspace
     def get_workspace(self, workspace_id, jwt):
         """This method will get a workspace by id
@@ -512,15 +507,14 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         return kdp_api.delete_user(config, user_id)
 
-
-
     # audit log configs
-    def get_audit_log_configs(self, jwt: str, keep_forever:bool = None, workspace_id:str = None,
-        limit:int = 10, skip:int=0, sort:object=None, filter:object=None) -> AuditLogConfigurationPaginator:
+    def get_audit_log_configs(self, jwt: str, keep_forever: bool = None, workspace_id: str = None,
+                              limit: int = 10, skip: int = 0, sort: object = None, filter: object = None) -> AuditLogConfigurationPaginator:
         """This method returns a AuditLogConfigurationPaginator object which contains list of AuditLogConfiguration objects.
 
             :param Configuration config: Connection configuration
             :param bool keep_forever: filter on keepForever flag.
+            :param jwt: Auth: Json Web Token
             :param str workspace_id: filter on workspace ID.
             :param int limit: max number of results in the response.
             :param int skip: how many records to skip before returning first record.
@@ -533,14 +527,13 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         audit_log_configs_api = AuditLogConfigsApi(configuration=config)
         return audit_log_configs_api.get_audit_log_configs(config=config, keep_forever=keep_forever, workspace_id=workspace_id,
-            limit=limit, skip=skip, sort=sort, filter=filter)
+                                                           limit=limit, skip=skip, sort=sort, filter=filter)
 
-
-
-    def patch_audit_log_configs(self, jwt: str, id:str, keep_forever:bool, age_in_days: int) -> AuditLogConfiguration:
+    def patch_audit_log_configs(self, jwt: str, id: str, keep_forever: bool, age_in_days: int) -> AuditLogConfiguration:
         """This method updates AuditLogConfiguration object.
 
             :param Configuration config: Connection configuration
+            :param jwt: Authentication: Json Web Token
             :param str id: audit log config id
             :param bool keep_forever: keepForever flag.
             :param int age_in_days: number of days to keep the records if keep_forever flag is false.
@@ -552,11 +545,11 @@ class KdpConn(object):
         audit_log_configs_api = AuditLogConfigsApi(configuration=config)
         return audit_log_configs_api.patch_audit_log_configs(config=config, id=id, keep_forever=keep_forever, age_in_days=age_in_days);
 
-
     # audit log
     def post_audit_log_query(self, jwt: str, dataset_id: str, expression: str, limit: int = 5, offset: int = 0) -> AuditLogPaginator:
         """This method will be used to query data in KDP datasets using the lucene syntax
 
+            :param jwt: Authentication: Json Web Token
             :param str dataset_id: audit log dataset id
             :param str expression: Lucene style query expression ex. name: John
             :param int limit: max number of results in the response.
